var indexSectionsWithContent =
{
  0: "_bdghlmpt",
  1: "_t",
  2: "m",
  3: "gt",
  4: "bdghlmpt",
  5: "pt",
  6: "t",
  7: "t",
  8: "t"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "variables",
  5: "typedefs",
  6: "enums",
  7: "enumvalues",
  8: "defines"
};

var indexSectionLabels =
{
  0: "All",
  1: "Data Structures",
  2: "Files",
  3: "Functions",
  4: "Variables",
  5: "Typedefs",
  6: "Enumerations",
  7: "Enumerator",
  8: "Macros"
};

